# 简介

hypium是HarmonyOS平台的UI自动化测试框架，支持开发者使用python语言为应用编写UI自动化测试脚本，主要包含以下特性：

1. hypium提供了原生控件/图像/比例坐标等**多种控件定位能力**，支持多窗口操作以及触摸屏/鼠标/键盘等**多种模拟输入功能**，支持**多设备**并行操作，能够覆盖各类场景和多种形态设备上的自动化用例编写需求。
2. hypium包含配套**用例编写辅助插件**, 支持控件查看/投屏操作等多种用例开发辅助功能，提升用例开发体验和效率。
3. hypium能够为执行的用例生成详细的**用例执行报告**，并且自动记录设备日志以及执行步骤截图，为开发者和测试人员提供高效和专业的测试用例执行和结果分析体验。

更多信息请通过华为开发者联盟官网获取最新的赋能套件，其中包含测试指南章节
